<p align="center">
  <img src="https://github.com/LorenzoPiu/Images/blob/main/Logo-0.0.8.png" width="35%">
</p>

#

A Python package to process combustion DNS.

## Installation

Run the following command to install:

```python
pip install -i https://test.pypi.org/simple/ aPriori
```


